Crate scyllax_parser

source ·
A parser for CQL queries See the source code and tests for examples of usage (for now).

Re-exports

Modules

Enums

Functions

  • Parse a CQL query.
  • Parse a file that can contain multiple CQL queries. The queries are separated by a semicolon. There may be an indeterminate number of newlines between the semicolon and the next query.